PrinterStatus class

A snapshot of the printer state emitted on the status stream.

Constructors

PrinterStatus({required PrinterConnectionState state, BrotherPrintError? error})
const

Properties

error BrotherPrintError?
Present when state is PrinterConnectionState.error.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state PrinterConnectionState
Current connection state.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited